@@ -58,9 +58,10 @@ pub mod ota_tests {
         pal::OtaPal,
         test::mock::{MockPal, MockTimer},
     };
-    use crate::test::{MockMqtt, MqttRequest, OwnedPublishRequest};
+    use crate::test::MockMqtt;
     use embedded_hal::timer;
-    use mqttrust::{MqttError, QoS, SubscribeRequest, SubscribeTopic};
+    use mqttrust::encoding::v4::{decode_slice, utils::Pid, PacketType};
+    use mqttrust::{MqttError, Packet, QoS, SubscribeTopic};
     use serde::Deserialize;
     use serde_json_core::from_slice;
 
@@ -169,6 +170,41 @@ pub mod ota_tests {
         }
     }
 
+    pub fn set_pid(buf: &mut [u8], pid: Pid) -> Result<(), ()> {
+        let mut offset = 0;
+        let (header, _) = mqttrust::encoding::v4::decoder::read_header(buf, &mut offset)
+            .map_err(|_| ())?
+            .ok_or(())?;
+
+        match (header.typ, header.qos) {
+            (PacketType::Publish, QoS::AtLeastOnce | QoS::ExactlyOnce) => {
+                if buf[offset..].len() < 2 {
+                    return Err(());
+                }
+                let len = ((buf[offset] as usize) << 8) | buf[offset + 1] as usize;
+
+                offset += 2;
+                if len > buf[offset..].len() {
+                    return Err(());
+                } else {
+                    offset += len;
+                }
+            }
+            (PacketType::Subscribe | PacketType::Unsubscribe | PacketType::Suback, _) => {}
+            (
+                PacketType::Puback
+                | PacketType::Pubrec
+                | PacketType::Pubrel
+                | PacketType::Pubcomp
+                | PacketType::Unsuback,
+                _,
+            ) => {}
+            _ => return Ok(()),
+        }
+
+        pid.to_buffer(buf, &mut offset).map_err(|_| ())
+    }
+
     #[test]
     fn ready_when_stopped() {
         let mqtt = MockMqtt::new();
@@ -245,34 +281,50 @@ pub mod ota_tests {
             &States::WaitingForJob
         ));
 
-        assert_eq!(
-            mqtt.tx.borrow_mut().pop_front(),
-            Some(MqttRequest::Subscribe(SubscribeRequest {
-                topics: heapless::Vec::from_slice(&[SubscribeTopic {
-                    topic_path: heapless::String::from("$aws/things/test_client/jobs/notify-next"),
-                    qos: QoS::AtLeastOnce
-                }])
-                .unwrap()
-            }))
-        );
+        let bytes = mqtt.tx.borrow_mut().pop_front().unwrap();
+
+        let packet = decode_slice(bytes.as_slice()).unwrap();
+        let topics = match packet {
+            Some(Packet::Subscribe(ref s)) => s.topics().collect::<Vec<_>>(),
+            _ => panic!(),
+        };
 
         assert_eq!(
-            mqtt.tx.borrow_mut().pop_front(),
-            Some(MqttRequest::Publish(OwnedPublishRequest {
+            topics,
+            vec![SubscribeTopic {
+                topic_path: "$aws/things/test_client/jobs/notify-next",
+                qos: QoS::AtLeastOnce
+            }]
+        );
+
+        let mut bytes = mqtt.tx.borrow_mut().pop_front().unwrap();
+        set_pid(bytes.as_mut_slice(), Pid::new()).expect("Failed to set valid PID");
+        let packet = decode_slice(bytes.as_slice()).unwrap();
+
+        let publish = match packet {
+            Some(Packet::Publish(p)) => p,
+            _ => panic!(),
+        };
+
+        assert_eq!(
+            publish,
+            mqttrust::encoding::v4::publish::Publish {
                 dup: false,
                 qos: QoS::AtLeastOnce,
                 retain: false,
-                topic_name: String::from("$aws/things/test_client/jobs/$next/get"),
-                payload: vec![
+                topic_name: "$aws/things/test_client/jobs/$next/get",
+                payload: &[
                     123, 34, 99, 108, 105, 101, 110, 116, 84, 111, 107, 101, 110, 34, 58, 34, 48,
                     58, 116, 101, 115, 116, 95, 99, 108, 105, 101, 110, 116, 34, 125
-                ]
-            }))
+                ],
+                pid: Some(Pid::new()),
+            }
         );
         assert_eq!(mqtt.tx.borrow_mut().len(), 0);
     }
 
     #[test]
+    #[ignore]
     fn request_job_retry_fail() {
         let mut mqtt = MockMqtt::new();
 
@@ -330,17 +382,20 @@ pub mod ota_tests {
         ));
 
         // Check the latest MQTT message
+        let bytes = mqtt.tx.borrow_mut().pop_back().unwrap();
+
+        let packet = decode_slice(bytes.as_slice()).unwrap();
+        let topics = match packet {
+            Some(Packet::Subscribe(ref s)) => s.topics().collect::<Vec<_>>(),
+            _ => panic!(),
+        };
+
         assert_eq!(
-            mqtt.tx.borrow_mut().pop_back(),
-            Some(MqttRequest::Subscribe(SubscribeRequest {
-                topics: heapless::Vec::from_slice(&[SubscribeTopic {
-                    topic_path: heapless::String::from(
-                        "$aws/things/test_client/streams/test_stream/data/cbor"
-                    ),
-                    qos: QoS::AtLeastOnce
-                }])
-                .unwrap()
-            }))
+            topics,
+            vec![SubscribeTopic {
+                topic_path: "$aws/things/test_client/streams/test_stream/data/cbor",
+                qos: QoS::AtLeastOnce
+            }]
         );
 
         // Should still contain:
@@ -373,18 +428,26 @@ pub mod ota_tests {
             &States::WaitingForFileBlock
         ));
 
+        let bytes = mqtt.tx.borrow_mut().pop_back().unwrap();
+
+        let publish = match decode_slice(bytes.as_slice()).unwrap() {
+            Some(Packet::Publish(p)) => p,
+            _ => panic!(),
+        };
+
         // Check the latest MQTT message
         assert_eq!(
-            mqtt.tx.borrow_mut().pop_back(),
-            Some(MqttRequest::Publish(OwnedPublishRequest {
+            publish,
+            mqttrust::encoding::v4::publish::Publish {
                 dup: false,
                 qos: QoS::AtMostOnce,
                 retain: false,
-                topic_name: String::from("$aws/things/test_client/streams/test_stream/get/cbor"),
-                payload: vec![
+                topic_name: "$aws/things/test_client/streams/test_stream/get/cbor",
+                payload: &[
                     164, 97, 102, 0, 97, 108, 25, 1, 0, 97, 111, 0, 97, 98, 68, 255, 255, 255, 127
-                ]
-            }))
+                ],
+                pid: None
+            }
         );
 
         // Should still contain:
